Column class

A single column in a table schema.

Constructors

Column(String name, ColumnType type)
const
Column.integer(String name)
Create an INTEGER column.
const
Column.real(String name)
Create a REAL column.
const
Column.text(String name)
Create a TEXT column.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the column.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ColumnType
Type of the column.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited