CrudEntry class

A single client-side change.

Constructors

CrudEntry(int clientId, UpdateType op, String table, String id, int? transactionId, Map<String, dynamic>? opData, {Map<String, dynamic>? previousValues, String? metadata})
CrudEntry.fromRow(Row row)
factory

Properties

clientId → int
Auto-incrementing client-side id.
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
ID of the changed row.
final
metadata → String?
An optional metadata string attached to this entry at the time the write has been issued.
final
op → UpdateType
Type of change.
final
opData → Map<String, dynamic>?
Data associated with the change.
final
previousValues → Map<String, dynamic>?
Old values before an update.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → String
Table that contained the change.
final
transactionId → int?
Auto-incrementing transaction id. This is the same for all operations within the same transaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the change to JSON format, as required by the dev crud API.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override