CrudTransaction class

Constructors

CrudTransaction({required List<CrudEntry> crud, required Future<void> complete({String? writeCheckpoint}), required int? transactionId})

Properties

complete → Future<void> Function({String? writeCheckpoint})
Call to remove the changes from the local queue, once successfully uploaded.
final
crud → List<CrudEntry>
List of client-side changes.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionId → int?
Unique transaction id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited