IndexedColumn class

Describes an indexed column.

Constructors

IndexedColumn(String column, {bool ascending = true})
const
IndexedColumn.ascending(String column)
const
IndexedColumn.descending(String column)
const

Properties

ascending → bool
Whether this column is stored in ascending order in the index.
final
column → String
Name of the column to index.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Table table) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited