PowerSyncSQLCipherOpenFactory class

A factory for opening a database with SQLCipher encryption. An encryption key is required to open the database.

Inheritance

Constructors

PowerSyncSQLCipherOpenFactory({required String path, required String key, SqliteOptions sqliteOptions = defaultOptions})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
final
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqliteOptions → SqliteOptions
finalinherited

Methods

enableExtension() → void
inherited
getLibraryForPlatform({String? path}) → String
Returns the library name for the current platform. path is optional and is used when the library is not in the default location.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(SqliteOpenOptions options) → CommonDatabase
Opens a direct connection to a SQLite database connection and executes setup pragma statements to initialize the DB
inherited
openConnection(SqliteOpenOptions options) → FutureOr<SqliteConnection>
Opens an asynchronous SqliteConnection to a SQLite database and executes setup pragma statements to initialize the DB
inherited
openDB(SqliteOpenOptions options) → CommonDatabase
Opens a direct connection to a SQLite database connection
inherited
pragmaStatements(SqliteOpenOptions options) → List<String>
inherited
setupFunctions(CommonDatabase db) → void
inherited
sleep(Duration duration) → void
On native platforms, synchronously pauses the current isolate for the given Duration.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited