ProgressWithOperations class final

Information about a progressing download.

This reports the total amount of operations to download, how many of them have already been completed and finally a fraction indicating relative progress (as a number between 0.0 and 1.0, inclusive)

To obtain these values, use SyncDownloadProgress available through SyncStatus.downloadProgress.

Properties

downloadedFraction → double
Relative progress (as a number between 0.0 and 1.0).
no setter
downloadedOperations → int
How many operations have already been downloaded since the last complete download.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalOperations → int
How many operations need to be downloaded in total until the current download is complete.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited