schema property
For RawTable.inferred tables, the schema from which put and delete statemenst are inferred.
Implementation
final RawTableSchema? schema;
For RawTable.inferred tables, the schema from which put and delete statemenst are inferred.
final RawTableSchema? schema;