RawTableSchema class final

The schema of a RawTable in the local database.

This information is optional when declaring raw tables with RawTable.new. However, providing it allows the sync client to infer RawTable.put and RawTable.delete statements automatically.

Constructors

RawTableSchema({String? tableName, List<String>? syncedColumns, TableOptions options = const TableOptions()})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
options TableOptions
Common options affecting how the powersync_create_raw_table_crud_trigger SQL function generates triggers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncedColumns List<String>?
An optional filter of columns that should be synced.
final
tableName String?
The actual name of the raw table in the local schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited