tableName property
The actual name of the raw table in the local schema.
Unlike RawTable.name, which describes the name of synced tables to
match, this reflects the local SQLite table name. This is used to infer
RawTable.put and RawTable.delete statements for the sync client. It
can also be used to auto-generate triggers forwarding writes on raw tables
into the CRUD upload queue (using the powersync_create_raw_table_crud_trigger
SQL function).
When set to null, defaults to the RawTable.name.
Implementation
final String? tableName;