Schema class

The schema used by the database.

The implementation uses the schema as a "VIEW" on top of JSON data. No migrations are required on the client.

Constructors

Schema(List<Table> tables, {List<RawTable> rawTables = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rawTables → List<RawTable>
A list of RawTables in addition to PowerSync-managed tables.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tables → List<Table>
List of tables in the schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited