SyncOptions class final

Options that affect how the sync client connects to the sync service.

Constructors

SyncOptions({Duration? crudThrottleTime, Duration? retryDelay, Map<String, dynamic>? params, SyncClientImplementation syncImplementation = SyncClientImplementation.defaultClient, bool? includeDefaultStreams, Map<String, String>? appMetadata})
const

Properties

appMetadata → Map<String, String>?
A map of application metadata that is passed to the PowerSync service.
final
crudThrottleTime → Duration?
A throttle to apply when listening for local database changes before scheduling them for uploads.
final
hashCode → int
The hash code for this object.
no setterinherited
includeDefaultStreams → bool?
Whether streams that have been defined with auto_subscribe: true should be synced when they don't have an explicit subscription.
final
params → Map<String, dynamic>?
A JSON object that is passed to the sync service and forwarded to sync rules.
final
retryDelay → Duration?
How long PowerSync should wait before reconnecting after an error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncImplementation → SyncClientImplementation
The SyncClientImplementation to use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited