SyncStatus class final

Properties

anyError → Object?
Get the current downloadError or uploadError.
no setter
connected → bool
true if currently connected.
final
connecting → bool
true if the PowerSync connection is busy connecting.
final
downloadError → Object?
Error during downloading (including connecting).
final
downloading → bool
true if actively downloading changes.
final
downloadProgress → SyncDownloadProgress?
A realtime progress report on how many operations have been downloaded and how many are necessary in total to complete the next sync iteration.
final
hashCode → int
The hash code for this object.
no setteroverride
hasSynced → bool?
Indicates whether there has been at least one full sync, if any. Is null when unknown, for example when state is still being loaded from the database.
final
lastSyncedAt → DateTime?
Time that a last sync has fully completed, if any.
final
priorityStatusEntries → List<SyncPriorityStatus>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncStreams → Iterable<SyncStreamStatus>?
All sync streams currently being tracked in the database.
no setter
uploadError → Object?
Error during uploading.
final
uploading → bool
true if uploading changes
final

Methods

copyWith({bool? connected, bool? downloading, bool? uploading, bool? connecting, Object? uploadError, Object? downloadError, DateTime? lastSyncedAt, bool? hasSynced, List<SyncPriorityStatus>? priorityStatusEntries}) → SyncStatus
forStream(SyncStreamDescription stream) → SyncStreamStatus?
If the stream appears in syncStreams, returns the current status for that stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
statusForPriority(StreamPriority priority) → SyncPriorityStatus
Returns information for lastSyncedAt and hasSynced information at a partial sync priority, or null if the status for that priority is unknown.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override