SyncStream class abstract interface

A handle to a SyncStreamDescription that allows subscribing to the stream.

To obtain an instance of SyncStream, call PowerSyncDatabase.syncStream.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the stream as it appears in the stream definition for the PowerSync service.
no setterinherited
parameters → Map<String, Object?>?
The parameters used to subscribe to the stream, if any.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe({Duration? ttl, StreamPriority? priority}) → Future<SyncStreamSubscription>
Adds a subscription to this stream, requesting it to be included when connecting to the sync service.
toString() → String
A string representation of this object.
inherited
unsubscribeAll() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited