SyncStreamStatus class final

Current information about a SyncStream that the sync client is subscribed to.

Properties

hashCode → int
The hash code for this object.
no setterinherited
priority → StreamPriority
The StreamPriority of the current stream.
no setter
progress → ProgressWithOperations?
If the SyncStatus is currently SyncStatus.downloading, download progress for this stream.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription → SyncSubscriptionDescription
The SyncSubscriptionDescription providing information about the current stream state.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited