SyncStreamSubscription class abstract interface

A SyncStream that has been subscribed to.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the stream as it appears in the stream definition for the PowerSync service.
no setterinherited
parameters → Map<String, Object?>?
The parameters used to subscribe to the stream, if any.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unsubscribe() → void
Removes this subscription.
waitForFirstSync() → Future<void>
A variant of PowerSyncDatabase.waitForFirstSync that is specific to this stream subscription.

Operators

operator ==(Object other) → bool
The equality operator.
inherited