SyncSubscriptionDescription class abstract interface

Information about a subscribed sync stream.

This includes the SyncStreamDescription along with information about the current sync status.

Inheritance

Properties

active → bool
Whether this stream is active, meaning that the subscription has been acknowledged by the sync serivce.
no setter
expiresAt → DateTime?
For sync streams that have a time-to-live, the current time at which the stream would expire if not subscribed to again.
no setter
hasExplicitSubscription → bool
Whether this stream has been subscribed to explicitly.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasSynced → bool
Whether this stream subscription has been synced at least once.
no setter
isDefault → bool
Whether this stream subscription is included by default, regardless of whether the stream has explicitly been subscribed to or not.
no setter
lastSyncedAt → DateTime?
If hasSynced is true, the last time data from this stream has been synced.
no setter
name → String
The name of the stream as it appears in the stream definition for the PowerSync service.
no setterinherited
parameters → Map<String, Object?>?
The parameters used to subscribe to the stream, if any.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited