RawTable.inferred constructor
const
RawTable.inferred({
- required String name,
- required RawTableSchema schema,
- PendingStatement? put,
- PendingStatement? delete,
- String? clear,
Creates a raw table where put and delete statements are optional
because the sync client can infer defaults from the schema of the table
in the local database.
Implementation
const RawTable.inferred({
required this.name,
required RawTableSchema this.schema,
this.put,
this.delete,
this.clear,
});