syncedColumns property
An optional filter of columns that should be synced.
By default, all columns in raw tables are considered for sync. If a filter is specified, PowerSync treats unmatched columns as local-only and will not attempt to sync them.
Implementation
final List<String>? syncedColumns;