TableOptions class final
Common options that can be applied on Table and RawTable (through RawTableSchema).
Constructors
- TableOptions({bool trackMetadata = false, TrackPreviousValuesOptions? trackPreviousValues, bool localOnly = false, bool insertOnly = false, bool ignoreEmptyUpdates = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreEmptyUpdates → bool
-
Whether an
UPDATEstatement that doesn't change any values should be ignored when creating CRUD entries.final - insertOnly → bool
-
Whether this is an insert-only table.
final
- localOnly → bool
-
Whether the table only exists locally.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackMetadata → bool
-
Whether to add a hidden
_metadatacolumn that will be enabled for updates to attach custom information about writes that will be reported through CrudEntry.metadata.final - trackPreviousValues → TrackPreviousValuesOptions?
-
Whether to track old values of columns for CrudEntry.previousValues.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited